All of lore.kernel.org
 help / color / mirror / Atom feed
From: Thomas Gleixner <tglx@linutronix.de>
To: LKML <linux-kernel@vger.kernel.org>
Cc: x86@kernel.org, David Woodhouse <dwmw2@infradead.org>,
	Andrew Cooper <andrew.cooper3@citrix.com>,
	Brian Gerst <brgerst@gmail.com>,
	Arjan van de Veen <arjan@linux.intel.com>,
	Paolo Bonzini <pbonzini@redhat.com>,
	Paul McKenney <paulmck@kernel.org>,
	Tom Lendacky <thomas.lendacky@amd.com>,
	Sean Christopherson <seanjc@google.com>,
	Oleksandr Natalenko <oleksandr@natalenko.name>,
	Paul Menzel <pmenzel@molgen.mpg.de>,
	"Guilherme G. Piccoli" <gpiccoli@igalia.com>,
	Piotr Gorski <lucjan.lucjanov@gmail.com>,
	Usama Arif <usama.arif@bytedance.com>,
	Juergen Gross <jgross@suse.com>,
	Boris Ostrovsky <boris.ostrovsky@oracle.com>,
	xen-devel@lists.xenproject.org,
	Russell King <linux@armlinux.org.uk>,
	Arnd Bergmann <arnd@arndb.de>,
	linux-arm-kernel@lists.infradead.org,
	Catalin Marinas <catalin.marinas@arm.com>,
	Will Deacon <will@kernel.org>, Guo Ren <guoren@kernel.org>,
	linux-csky@vger.kernel.org,
	Thomas Bogendoerfer <tsbogend@alpha.franken.de>,
	linux-mips@vger.kernel.org,
	"James E.J. Bottomley" <James.Bottomley@HansenPartnership.com>,
	Helge Deller <deller@gmx.de>,
	linux-parisc@vger.kernel.org,
	Paul Walmsley <paul.walmsley@sifive.com>,
	Palmer Dabbelt <palmer@dabbelt.com>,
	linux-riscv@lists.infradead.org,
	Mark Rutland <mark.rutland@arm.com>,
	Sabin Rapan <sabrapan@amazon.com>,
	"Michael Kelley (LINUX)" <mikelley@microsoft.com>
Subject: [patch V2 21/38] ARM: smp: Switch to hotplug core state synchronization
Date: Thu,  4 May 2023 21:02:32 +0200 (CEST)	[thread overview]
Message-ID: <20230504185937.477649111@linutronix.de> (raw)
In-Reply-To: 20230504185733.126511787@linutronix.de

From: Thomas Gleixner <tglx@linutronix.de>

Switch to the CPU hotplug core state tracking and synchronization
mechanim. No functional change intended.

Signed-off-by: Thomas Gleixner <tglx@linutronix.de>
Cc: Russell King <linux@armlinux.org.uk>
Cc: Arnd Bergmann <arnd@arndb.de>
Cc: linux-arm-kernel@lists.infradead.org

---
 arch/arm/Kconfig           |    1 +
 arch/arm/include/asm/smp.h |    2 +-
 arch/arm/kernel/smp.c      |   18 +++++++-----------
 3 files changed, 9 insertions(+), 12 deletions(-)
---
--- a/arch/arm/Kconfig
+++ b/arch/arm/Kconfig
@@ -124,6 +124,7 @@ config ARM
 	select HAVE_SYSCALL_TRACEPOINTS
 	select HAVE_UID16
 	select HAVE_VIRT_CPU_ACCOUNTING_GEN
+	select HOTPLUG_CORE_SYNC_DEAD if HOTPLUG_CPU
 	select IRQ_FORCED_THREADING
 	select MODULES_USE_ELF_REL
 	select NEED_DMA_MAP_STATE
--- a/arch/arm/include/asm/smp.h
+++ b/arch/arm/include/asm/smp.h
@@ -64,7 +64,7 @@ extern void secondary_startup_arm(void);
 
 extern int __cpu_disable(void);
 
-extern void __cpu_die(unsigned int cpu);
+static inline void __cpu_die(unsigned int cpu) { }
 
 extern void arch_send_call_function_single_ipi(int cpu);
 extern void arch_send_call_function_ipi_mask(const struct cpumask *mask);
--- a/arch/arm/Kconfig
+++ b/arch/arm/Kconfig
@@ -124,6 +124,7 @@ config ARM
 	select HAVE_SYSCALL_TRACEPOINTS
 	select HAVE_UID16
 	select HAVE_VIRT_CPU_ACCOUNTING_GEN
+	select HOTPLUG_CORE_SYNC_DEAD if HOTPLUG_CPU
 	select IRQ_FORCED_THREADING
 	select MODULES_USE_ELF_REL
 	select NEED_DMA_MAP_STATE
--- a/arch/arm/include/asm/smp.h
+++ b/arch/arm/include/asm/smp.h
@@ -64,7 +64,7 @@ extern void secondary_startup_arm(void);
 
 extern int __cpu_disable(void);
 
-extern void __cpu_die(unsigned int cpu);
+static inline void __cpu_die(unsigned int cpu) { }
 
 extern void arch_send_call_function_single_ipi(int cpu);
 extern void arch_send_call_function_ipi_mask(const struct cpumask *mask);
--- a/arch/arm/Kconfig
+++ b/arch/arm/Kconfig
@@ -124,6 +124,7 @@ config ARM
 	select HAVE_SYSCALL_TRACEPOINTS
 	select HAVE_UID16
 	select HAVE_VIRT_CPU_ACCOUNTING_GEN
+	select HOTPLUG_CORE_SYNC_DEAD if HOTPLUG_CPU
 	select IRQ_FORCED_THREADING
 	select MODULES_USE_ELF_REL
 	select NEED_DMA_MAP_STATE
--- a/arch/arm/include/asm/smp.h
+++ b/arch/arm/include/asm/smp.h
@@ -64,7 +64,7 @@ extern void secondary_startup_arm(void);
 
 extern int __cpu_disable(void);
 
-extern void __cpu_die(unsigned int cpu);
+static inline void __cpu_die(unsigned int cpu) { }
 
 extern void arch_send_call_function_single_ipi(int cpu);
 extern void arch_send_call_function_ipi_mask(const struct cpumask *mask);
--- a/arch/arm/kernel/smp.c
+++ b/arch/arm/kernel/smp.c
@@ -288,15 +288,11 @@ int __cpu_disable(void)
 }
 
 /*
- * called on the thread which is asking for a CPU to be shutdown -
- * waits until shutdown has completed, or it is timed out.
+ * called on the thread which is asking for a CPU to be shutdown after the
+ * shutdown completed.
  */
-void __cpu_die(unsigned int cpu)
+void arch_cpuhp_cleanup_dead_cpu(unsigned int cpu)
 {
-	if (!cpu_wait_death(cpu, 5)) {
-		pr_err("CPU%u: cpu didn't die\n", cpu);
-		return;
-	}
 	pr_debug("CPU%u: shutdown\n", cpu);
 
 	clear_tasks_mm_cpumask(cpu);
@@ -336,11 +332,11 @@ void __noreturn arch_cpu_idle_dead(void)
 	flush_cache_louis();
 
 	/*
 	 * Tell __cpu_die() that this CPU is now safe to dispose of.  Once
 	 * this returns, power and/or clocks can be removed at any point
 	 * from this CPU and its cache by platform_cpu_kill().
 	 */
-	(void)cpu_report_death();
+	cpuhp_ap_report_dead();
 
 	/*
 	 * Ensure that the cache lines associated with that completion are


WARNING: multiple messages have this Message-ID (diff)
From: Thomas Gleixner <tglx@linutronix.de>
To: LKML <linux-kernel@vger.kernel.org>
Cc: x86@kernel.org, David Woodhouse <dwmw2@infradead.org>,
	Andrew Cooper <andrew.cooper3@citrix.com>,
	Brian Gerst <brgerst@gmail.com>,
	Arjan van de Veen <arjan@linux.intel.com>,
	Paolo Bonzini <pbonzini@redhat.com>,
	Paul McKenney <paulmck@kernel.org>,
	Tom Lendacky <thomas.lendacky@amd.com>,
	Sean Christopherson <seanjc@google.com>,
	Oleksandr Natalenko <oleksandr@natalenko.name>,
	Paul Menzel <pmenzel@molgen.mpg.de>,
	"Guilherme G. Piccoli" <gpiccoli@igalia.com>,
	Piotr Gorski <lucjan.lucjanov@gmail.com>,
	Usama Arif <usama.arif@bytedance.com>,
	Juergen Gross <jgross@suse.com>,
	Boris Ostrovsky <boris.ostrovsky@oracle.com>,
	xen-devel@lists.xenproject.org,
	Russell King <linux@armlinux.org.uk>,
	Arnd Bergmann <arnd@arndb.de>,
	linux-arm-kernel@lists.infradead.org,
	Catalin Marinas <catalin.marinas@arm.com>,
	Will Deacon <will@kernel.org>, Guo Ren <guoren@kernel.org>,
	linux-csky@vger.kernel.org,
	Thomas Bogendoerfer <tsbogend@alpha.franken.de>,
	linux-mips@vger.kernel.org,
	"James E.J. Bottomley" <James.Bottomley@HansenPartnership.com>,
	Helge Deller <deller@gmx.de>,
	linux-parisc@vger.kernel.org,
	Paul Walmsley <paul.walmsley@sifive.com>,
	Palmer Dabbelt <palmer@dabbelt.com>,
	linux-riscv@lists.infradead.org,
	Mark Rutland <mark.rutland@arm.com>,
	Sabin Rapan <sabrapan@amazon.com>,
	"Michael Kelley (LINUX)" <mikelley@microsoft.com>
Subject: [patch V2 21/38] ARM: smp: Switch to hotplug core state synchronization
Date: Thu,  4 May 2023 21:02:32 +0200 (CEST)	[thread overview]
Message-ID: <20230504185937.477649111@linutronix.de> (raw)
In-Reply-To: 20230504185733.126511787@linutronix.de

From: Thomas Gleixner <tglx@linutronix.de>

Switch to the CPU hotplug core state tracking and synchronization
mechanim. No functional change intended.

Signed-off-by: Thomas Gleixner <tglx@linutronix.de>
Cc: Russell King <linux@armlinux.org.uk>
Cc: Arnd Bergmann <arnd@arndb.de>
Cc: linux-arm-kernel@lists.infradead.org

---
 arch/arm/Kconfig           |    1 +
 arch/arm/include/asm/smp.h |    2 +-
 arch/arm/kernel/smp.c      |   18 +++++++-----------
 3 files changed, 9 insertions(+), 12 deletions(-)
---
@@ -336,11 +332,11 @@ void __noreturn arch_cpu_idle_dead(void)
 
 	/*
-	 * Tell __cpu_die() that this CPU is now safe to dispose of.  Once
-	 * this returns, power and/or clocks can be removed at any point
-	 * from this CPU and its cache by platform_cpu_kill().
+	 * Tell cpuhp_bp_sync_dead() that this CPU is now safe to dispose
+	 * of. Once this returns, power and/or clocks can be removed at
+	 * any point from this CPU and its cache by platform_cpu_kill().
 	 */
--- a/arch/arm/kernel/smp.c
+++ b/arch/arm/kernel/smp.c
@@ -288,15 +288,11 @@ int __cpu_disable(void)
 }
 
 /*
- * called on the thread which is asking for a CPU to be shutdown -
- * waits until shutdown has completed, or it is timed out.
+ * called on the thread which is asking for a CPU to be shutdown after the
+ * shutdown completed.
  */
-void __cpu_die(unsigned int cpu)
+void arch_cpuhp_cleanup_dead_cpu(unsigned int cpu)
 {
-	if (!cpu_wait_death(cpu, 5)) {
-		pr_err("CPU%u: cpu didn't die\n", cpu);
-		return;
-	}
 	pr_debug("CPU%u: shutdown\n", cpu);
 
 	clear_tasks_mm_cpumask(cpu);
@@ -336,11 +332,11 @@ void __noreturn arch_cpu_idle_dead(void)
 	flush_cache_louis();
 
 	/*
 	 * Tell __cpu_die() that this CPU is now safe to dispose of.  Once
 	 * this returns, power and/or clocks can be removed at any point
 	 * from this CPU and its cache by platform_cpu_kill().
 	 */
-	(void)cpu_report_death();
+	cpuhp_ap_report_dead();
 
 	/*
 	 * Ensure that the cache lines associated with that completion are


_______________________________________________
linux-riscv mailing list
linux-riscv@lists.infradead.org
http://lists.infradead.org/mailman/listinfo/linux-riscv

WARNING: multiple messages have this Message-ID (diff)
From: Thomas Gleixner <tglx@linutronix.de>
To: LKML <linux-kernel@vger.kernel.org>
Cc: x86@kernel.org, David Woodhouse <dwmw2@infradead.org>,
	Andrew Cooper <andrew.cooper3@citrix.com>,
	Brian Gerst <brgerst@gmail.com>,
	Arjan van de Veen <arjan@linux.intel.com>,
	Paolo Bonzini <pbonzini@redhat.com>,
	Paul McKenney <paulmck@kernel.org>,
	Tom Lendacky <thomas.lendacky@amd.com>,
	Sean Christopherson <seanjc@google.com>,
	Oleksandr Natalenko <oleksandr@natalenko.name>,
	Paul Menzel <pmenzel@molgen.mpg.de>,
	"Guilherme G. Piccoli" <gpiccoli@igalia.com>,
	Piotr Gorski <lucjan.lucjanov@gmail.com>,
	Usama Arif <usama.arif@bytedance.com>,
	Juergen Gross <jgross@suse.com>,
	Boris Ostrovsky <boris.ostrovsky@oracle.com>,
	xen-devel@lists.xenproject.org,
	Russell King <linux@armlinux.org.uk>,
	Arnd Bergmann <arnd@arndb.de>,
	linux-arm-kernel@lists.infradead.org,
	Catalin Marinas <catalin.marinas@arm.com>,
	Will Deacon <will@kernel.org>, Guo Ren <guoren@kernel.org>,
	linux-csky@vger.kernel.org,
	Thomas Bogendoerfer <tsbogend@alpha.franken.de>,
	linux-mips@vger.kernel.org,
	"James E.J. Bottomley" <James.Bottomley@HansenPartnership.com>,
	Helge Deller <deller@gmx.de>,
	linux-parisc@vger.kernel.org,
	Paul Walmsley <paul.walmsley@sifive.com>,
	Palmer Dabbelt <palmer@dabbelt.com>,
	linux-riscv@lists.infradead.org,
	Mark Rutland <mark.rutland@arm.com>,
	Sabin Rapan <sabrapan@amazon.com>,
	"Michael Kelley (LINUX)" <mikelley@microsoft.com>
Subject: [patch V2 21/38] ARM: smp: Switch to hotplug core state synchronization
Date: Thu,  4 May 2023 21:02:32 +0200 (CEST)	[thread overview]
Message-ID: <20230504185937.477649111@linutronix.de> (raw)
In-Reply-To: 20230504185733.126511787@linutronix.de

From: Thomas Gleixner <tglx@linutronix.de>

Switch to the CPU hotplug core state tracking and synchronization
mechanim. No functional change intended.

Signed-off-by: Thomas Gleixner <tglx@linutronix.de>
Cc: Russell King <linux@armlinux.org.uk>
Cc: Arnd Bergmann <arnd@arndb.de>
Cc: linux-arm-kernel@lists.infradead.org

---
 arch/arm/Kconfig           |    1 +
 arch/arm/include/asm/smp.h |    2 +-
 arch/arm/kernel/smp.c      |   18 +++++++-----------
 3 files changed, 9 insertions(+), 12 deletions(-)
---
@@ -336,11 +332,11 @@ void __noreturn arch_cpu_idle_dead(void)
 
 	/*
-	 * Tell __cpu_die() that this CPU is now safe to dispose of.  Once
-	 * this returns, power and/or clocks can be removed at any point
-	 * from this CPU and its cache by platform_cpu_kill().
+	 * Tell cpuhp_bp_sync_dead() that this CPU is now safe to dispose
+	 * of. Once this returns, power and/or clocks can be removed at
+	 * any point from this CPU and its cache by platform_cpu_kill().
 	 */
--- a/arch/arm/kernel/smp.c
+++ b/arch/arm/kernel/smp.c
@@ -288,15 +288,11 @@ int __cpu_disable(void)
 }
 
 /*
- * called on the thread which is asking for a CPU to be shutdown -
- * waits until shutdown has completed, or it is timed out.
+ * called on the thread which is asking for a CPU to be shutdown after the
+ * shutdown completed.
  */
-void __cpu_die(unsigned int cpu)
+void arch_cpuhp_cleanup_dead_cpu(unsigned int cpu)
 {
-	if (!cpu_wait_death(cpu, 5)) {
-		pr_err("CPU%u: cpu didn't die\n", cpu);
-		return;
-	}
 	pr_debug("CPU%u: shutdown\n", cpu);
 
 	clear_tasks_mm_cpumask(cpu);
@@ -336,11 +332,11 @@ void __noreturn arch_cpu_idle_dead(void)
 	flush_cache_louis();
 
 	/*
 	 * Tell __cpu_die() that this CPU is now safe to dispose of.  Once
 	 * this returns, power and/or clocks can be removed at any point
 	 * from this CPU and its cache by platform_cpu_kill().
 	 */
-	(void)cpu_report_death();
+	cpuhp_ap_report_dead();
 
 	/*
 	 * Ensure that the cache lines associated with that completion are
@@ -336,11 +332,11 @@ void __noreturn arch_cpu_idle_dead(void)
 
 	/*
-	 * Tell __cpu_die() that this CPU is now safe to dispose of.  Once
-	 * this returns, power and/or clocks can be removed at any point
-	 * from this CPU and its cache by platform_cpu_kill().
+	 * Tell cpuhp_bp_sync_dead() that this CPU is now safe to dispose
+	 * of. Once this returns, power and/or clocks can be removed at
+	 * any point from this CPU and its cache by platform_cpu_kill().
 	 */


_______________________________________________
linux-arm-kernel mailing list
linux-arm-kernel@lists.infradead.org
http://lists.infradead.org/mailman/listinfo/linux-arm-kernel

  parent reply	other threads:[~2023-05-04 19:03 UTC|newest]

Thread overview: 132+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2023-05-04 19:01 [patch V2 00/38] cpu/hotplug, x86: Reworked parallel CPU bringup Thomas Gleixner
2023-05-04 19:01 ` Thomas Gleixner
2023-05-04 19:01 ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 01/38] x86/smpboot: Cleanup topology_phys_to_logical_pkg()/die() Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 02/38] cpu/hotplug: Mark arch_disable_smp_support() and bringup_nonboot_cpus() __init Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 03/38] x86/smpboot: Avoid pointless delay calibration if TSC is synchronized Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 04/38] x86/smpboot: Rename start_cpu0() to soft_restart_cpu() Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 05/38] x86/topology: Remove CPU0 hotplug option Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 06/38] x86/smpboot: Remove the CPU0 hotplug kludge Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 07/38] x86/smpboot: Restrict soft_restart_cpu() to SEV Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 08/38] x86/smpboot: Split up native_cpu_up() into separate phases and document them Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 09/38] x86/smpboot: Get rid of cpu_init_secondary() Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 10/38] x86/cpu/cacheinfo: Remove cpu_callout_mask dependency Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 11/38] x86/smpboot: Move synchronization masks to SMP boot code Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 12/38] x86/smpboot: Make TSC synchronization function call based Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 13/38] x86/smpboot: Remove cpu_callin_mask Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 14/38] cpu/hotplug: Rework sparse_irq locking in bringup_cpu() Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 15/38] x86/smpboot: Remove wait for cpu_online() Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 16/38] x86/xen/smp_pv: Remove wait for CPU online Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 17/38] x86/xen/hvm: Get rid of DEAD_FROZEN handling Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 18/38] cpu/hotplug: Add CPU state tracking and synchronization Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 19/38] x86/smpboot: Switch to hotplug core state synchronization Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 20/38] cpu/hotplug: Remove cpu_report_state() and related unused cruft Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` Thomas Gleixner [this message]
2023-05-04 19:02   ` [patch V2 21/38] ARM: smp: Switch to hotplug core state synchronization Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 22/38] arm64: " Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 23/38] csky/smp: " Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 24/38] MIPS: SMP_CPS: " Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 25/38] parisc: " Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 26/38] riscv: " Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 27/38] cpu/hotplug: Remove unused state functions Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 28/38] cpu/hotplug: Reset task stack state in _cpu_up() Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 29/38] cpu/hotplug: Provide a split up CPUHP_BRINGUP mechanism Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 30/38] x86/smpboot: Enable split CPU startup Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 31/38] x86/apic: Provide cpu_primary_thread mask Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 32/38] cpu/hotplug: Allow "parallel" bringup up to CPUHP_BP_KICK_AP_STATE Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 33/38] x86/topology: Store extended topology leaf information Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 34/38] x86/cpu/amd; Invoke detect_extended_topology_early() on boot CPU Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 23:04   ` Andrew Cooper
2023-05-04 23:04     ` Andrew Cooper
2023-05-04 23:04     ` Andrew Cooper
2023-05-05 12:45     ` Thomas Gleixner
2023-05-05 12:45       ` Thomas Gleixner
2023-05-05 12:45       ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 35/38] x86/apic: Save the APIC virtual base address Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 36/38] x86/smpboot: Implement a bit spinlock to protect the realmode stack Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02 ` [patch V2 37/38] x86/smpboot: Support parallel startup of secondary CPUs Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:02   ` Thomas Gleixner
2023-05-04 19:03 ` [patch V2 38/38] x86/smpboot/64: Implement arch_cpuhp_init_parallel_bringup() and enable it Thomas Gleixner
2023-05-04 19:03   ` Thomas Gleixner
2023-05-04 19:03   ` Thomas Gleixner
2023-05-06  0:53   ` Michael Kelley (LINUX)
2023-05-06  0:53     ` Michael Kelley (LINUX)
2023-05-06  0:53     ` Michael Kelley (LINUX)
2023-05-06 16:22     ` Thomas Gleixner
2023-05-06 16:22       ` Thomas Gleixner
2023-05-06 16:22       ` Thomas Gleixner
2023-05-07  4:14       ` Michael Kelley (LINUX)
2023-05-07  4:14         ` Michael Kelley (LINUX)
2023-05-07  4:14         ` Michael Kelley (LINUX)

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20230504185937.477649111@linutronix.de \
    --to=tglx@linutronix.de \
    --cc=James.Bottomley@HansenPartnership.com \
    --cc=andrew.cooper3@citrix.com \
    --cc=arjan@linux.intel.com \
    --cc=arnd@arndb.de \
    --cc=boris.ostrovsky@oracle.com \
    --cc=brgerst@gmail.com \
    --cc=catalin.marinas@arm.com \
    --cc=deller@gmx.de \
    --cc=dwmw2@infradead.org \
    --cc=gpiccoli@igalia.com \
    --cc=guoren@kernel.org \
    --cc=jgross@suse.com \
    --cc=linux-arm-kernel@lists.infradead.org \
    --cc=linux-csky@vger.kernel.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=linux-mips@vger.kernel.org \
    --cc=linux-parisc@vger.kernel.org \
    --cc=linux-riscv@lists.infradead.org \
    --cc=linux@armlinux.org.uk \
    --cc=lucjan.lucjanov@gmail.com \
    --cc=mark.rutland@arm.com \
    --cc=mikelley@microsoft.com \
    --cc=oleksandr@natalenko.name \
    --cc=palmer@dabbelt.com \
    --cc=paul.walmsley@sifive.com \
    --cc=paulmck@kernel.org \
    --cc=pbonzini@redhat.com \
    --cc=pmenzel@molgen.mpg.de \
    --cc=sabrapan@amazon.com \
    --cc=seanjc@google.com \
    --cc=thomas.lendacky@amd.com \
    --cc=tsbogend@alpha.franken.de \
    --cc=usama.arif@bytedance.com \
    --cc=will@kernel.org \
    --cc=x86@kernel.org \
    --cc=xen-devel@lists.xenproject.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.